@@ -302,46 +302,6 @@ class Watchpack extends EventEmitter {
 		return map;
 	}
 
-	_missingWatcher(file, watcher) {
-		if (watcher) {
-			watcher.on("change", (mtime, type) => {
-				this._onChange(file, mtime, file, type);
-			});
-			watcher.on("remove", type => {
-				this._onRemove(file, file, type);
-			});
-		}
-		return watcher;
-	}
-
-	_fileWatcher(file, watcher) {
-		if (watcher) {
-			watcher.on("initial-missing", type => {
-				this._onRemove(file, file, type);
-			});
-			watcher.on("change", (mtime, type) => {
-				this._onChange(file, mtime, file, type);
-			});
-			watcher.on("remove", type => {
-				this._onRemove(file, file, type);
-			});
-		}
-		return watcher;
-	}
-
-	_dirWatcher(item, watcher) {
-		watcher.on("initial-missing", type => {
-			this._onRemove(item, item, type);
-		});
-		watcher.on("change", (file, mtime, type) => {
-			this._onChange(item, mtime, file, type);
-		});
-		watcher.on("remove", type => {
-			this._onRemove(item, item, type);
-		});
-		return watcher;
-	}
-
 	_onChange(item, mtime, file, type) {
 		file = file || item;
 		if (this.paused) return;
